==> downloads.html?file=gigkalender_v1.2.80_040.zip: gigkalender/guestbook/guestbook.php <==
<?php
/*
    CREATIVE COMMONS - Attribution-No Derivative Works 3.0 Germany:
    - You may not alter, transform, or build upon this work.
    - Dieses Werk darf nicht bearbeitet oder in anderer Weise verändert werden.
*/

  $Path = str_replace('\\','/', __FILE__);
  $Path = str_replace('guestbook/guestbook.php', '', $Path);
  
  include_once ($Path."includes/error_reporting.php");
  include_once ($Path."gigkalender.ini.php");
  include_once ($Path."functions/standard.php");
  include_once ($Path."guestbook/functions.php");
  include_once ($Path."includes/frontend_language_selector.php");

  foreach ($_GET as $key => $value) {
    $$key = trim($value);
    $$key = stripslashes($$key);
    $$key = strip_tags($$key); }
  foreach ($_POST as $key => $value) {
    $$key = trim($value); // ' -1\2'3"4<b>5&6; ' => '-1\2'3"4<b>5&6;'
    $$key = html_entity_decode($$key); // '&lt;b&gt;dog&lt;/b&gt;' => <b>dog</b>
    $$key = htmlspecialchars_decode($$key); // 'this -&gt; &quot;' => 'this -> "'
    $$key = stripslashes($$key); // O\'reilly? => O'reilly
    $$key = strip_tags($$key); // 'Hi <b>there</b>' => 'Hi there'
    $$key = htmlentities($$key); } // for displaying in the form

  if (!isset($gb_page)) $gb_page='';
  
  if ($gb_page=='' OR is_numeric($gb_page) OR $gb_page=='show' )
    include_once ($Path."guestbook/guestbook_show.php");
  elseif ($gb_page == 'form')
    include_once ($Path."guestbook/guestbook_form.php");
  elseif ($gb_page == 'mail')
    include_once ($Path."guestbook/guestbook_mail.php");
  elseif ($gb_page == 'edit')
    include_once ($Path."guestbook/guestbook_edit.php");
  elseif ($gb_page == 'delete')
    include_once ($Path."guestbook/guestbook_delete.php");

?>

==> downloads.html?file=gigkalender_v1.2.80_146.zip: gigkalender/guestbook/guestbook.php <==
<?php
/*
    CREATIVE COMMONS - Attribution-No Derivative Works 3.0 Germany:
    - You may not alter, transform, or build upon this work.
    - Dieses Werk darf nicht bearbeitet oder in anderer Weise verändert werden.
*/
  $Path = str_replace('\\','/', __FILE__);
  $Path = str_replace('guestbook/guestbook.php', '', $Path);
  
  include_once ($Path."includes/error_reporting.php");
  include_once ($Path."gigkalender.ini.php");
  include_once ($Path."functions/standard.php");
  include_once ($Path."guestbook/functions.php");
  include_once ($Path."includes/frontend_language_selector.php");

  foreach ($_GET as $key => $value) {
    $$key = trim($value);
    $$key = stripslashes($$key);
    $$key = strip_tags($$key); }
  foreach ($_POST as $key => $value) {
    $$key = trim($value); // ' -1\2'3"4<b>5&6; ' => '-1\2'3"4<b>5&6;'
    $$key = html_entity_decode($$key); // '&lt;b&gt;dog&lt;/b&gt;' => <b>dog</b>
    $$key = htmlspecialchars_decode($$key); // 'this -&gt; &quot;' => 'this -> "'
    $$key = stripslashes($$key); // O\'reilly? => O'reilly
    $$key = strip_tags($$key); // 'Hi <b>there</b>' => 'Hi there'
    $$key = htmlentities($$key); } // for displaying in the form

  if (!isset($gb_page)) $gb_page='';

  if ($gb_page=='' OR is_numeric($gb_page) OR $gb_page=='show' )
    include_once ($Path."guestbook/guestbook_show.php");
  elseif ($gb_page == 'form')
    include_once ($Path."guestbook/guestbook_form_internal.php");
  elseif ($gb_page == 'mail')
    include_once ($Path."guestbook/guestbook_mail.php");
  elseif ($gb_page == 'edit')
    include_once ($Path."guestbook/guestbook_edit.php");
  elseif ($gb_page == 'delete')
    include_once ($Path."guestbook/guestbook_delete.php");

?>
